@@ -15,16 +15,11 @@ class conexao(object):
             self.__conn.autocommit = False
             self.__cur = self.__conn.cursor()
         elif nome_conexao == "dbmakerodbc":
-            #self.__conn = pyodbc.connect("DSN=%s" %db)
             self.__conn = pyodbc.connect(f'DSN={db};UID={usr};PWD={pwd}')
             self.__conn.autocommit = False
             self.__cur = self.__conn.cursor()
         elif nome_conexao == "sqlserverodbc":
-            if not usr:
-                self.__conn = pyodbc.connect(f'DSN={db}')
-            else:
-                self.__conn = pyodbc.connect(f'DSN={db};UID={usr};PWD={pwd}')
-            
+            self.__conn = pyodbc.connect(f'DSN={db};UID={usr};PWD={pwd}')
             self.__conn.autocommit = False
             self.__cur = self.__conn.cursor()
         elif nome_conexao == "firebird":
